@@ -4,8 +4,7 @@ function (eS, lambda, alpha)
   mat <- exprs(eS)
   if (length(alpha)==1) {
     mat.cor <- mat-alpha
-  } 
-  else {
+  } else {
     r <- dim(mat)[1]
     onevec <- matrix(1, nrow=r, ncol=1)
     mat.cor <- mat - onevec %*% alpha
